==> com.liferay.dynamic.data.mapping.form.renderer-5.0.27.jar: META-INF/resources/js/components/Field/MetalFieldAdapter.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.27/js/components/Field/MetalFieldAdapter.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './MetalFieldAdapter.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _MetalFieldAdapter = _interopRequireDefault(require("./MetalFieldAdapter.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var MetalFieldAdapter =
  /*#__PURE__*/
  function (_Component) {
    _inherits(MetalFieldAdapter, _Component);

    function MetalFieldAdapter() {
      _classCallCheck(this, MetalFieldAdapter);

      return _possibleConstructorReturn(this, _getPrototypeOf(MetalFieldAdapter).apply(this, arguments));
    }

    _createClass(MetalFieldAdapter, [{
      key: "getChildContext",
      value: function getChildContext() {
        return {
          dispatch: this._handleDispatch,
          store: {
            editingLanguageId: this.editingLanguageId
          }
        };
      }
    }, {
      key: "_handleDispatch",
      value: function _handleDispatch(name, event) {
        switch (name) {
          case 'fieldRemoved':
            this.onRemoved(name, event);
            break;

          case 'fieldRepeated':
            this.onRepeated(name, event);
            break;

          default:
            new TypeError("".concat(name, " event is not supported."));
            break;
        }
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        // Sends the empty value, the `blur` event does not need to
        // know this information only that the event was triggered.
        this.onBlur(event, '');
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        var originalEvent = event.originalEvent,
            value = event.value;
        this.onChange(originalEvent, value);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        // Sends the empty value, the `focus` event does not need to
        // know this information only that the event was triggered.
        this.onFocus(event, '');
      }
    }]);

    return MetalFieldAdapter;
  }(_metalComponent["default"]);

  MetalFieldAdapter.STATE = {
    activePage: _metalState.Config.number(),
    editable: _metalState.Config.bool(),
    editingLanguageId: _metalState.Config.string(),
    field: _metalState.Config.any(),
    onBlur: _metalState.Config.any(),
    onChange: _metalState.Config.any(),
    onFocus: _metalState.Config.any(),
    pageIndex: _metalState.Config.number(),
    spritemap: _metalState.Config.string(),
    type: _metalState.Config.string()
  };

  _metalSoy["default"].register(MetalFieldAdapter, _MetalFieldAdapter["default"]);

  var _default = MetalFieldAdapter;
  exports["default"] = _default;
  //# sourceMappingURL=MetalFieldAdapter.es.js.map
});
//# sourceMappingURL=MetalFieldAdapter.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.33.jar: META-INF/resources/js/components/Field/MetalFieldAdapter.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.33/js/components/Field/MetalFieldAdapter.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './MetalFieldAdapter.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _MetalFieldAdapter = _interopRequireDefault(require("./MetalFieldAdapter.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var MetalFieldAdapter = /*#__PURE__*/function (_Component) {
    _inherits(MetalFieldAdapter, _Component);

    function MetalFieldAdapter() {
      _classCallCheck(this, MetalFieldAdapter);

      return _possibleConstructorReturn(this, _getPrototypeOf(MetalFieldAdapter).apply(this, arguments));
    }

    _createClass(MetalFieldAdapter, [{
      key: "getChildContext",
      value: function getChildContext() {
        return {
          dispatch: this._handleDispatch.bind(this),
          store: {
            editingLanguageId: this.editingLanguageId
          }
        };
      }
    }, {
      key: "_handleDispatch",
      value: function _handleDispatch(name, event) {
        switch (name) {
          case 'fieldRemoved':
            this.onRemoved(name, event);
            break;

          case 'fieldRepeated':
            this.onRepeated(name, event);
            break;

          default:
            new TypeError("".concat(name, " event is not supported."));
            break;
        }
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        // Sends the empty value, the `blur` event does not need to
        // know this information only that the event was triggered.
        this.onBlur(event, '');
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        var originalEvent = event.originalEvent,
            value = event.value;
        this.onChange(originalEvent, value);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        // Sends the empty value, the `focus` event does not need to
        // know this information only that the event was triggered.
        this.onFocus(event, '');
      }
    }]);

    return MetalFieldAdapter;
  }(_metalComponent["default"]);

  MetalFieldAdapter.STATE = {
    activePage: _metalState.Config.number(),
    editable: _metalState.Config.bool(),
    editingLanguageId: _metalState.Config.string(),
    field: _metalState.Config.any(),
    onBlur: _metalState.Config.any(),
    onChange: _metalState.Config.any(),
    onFocus: _metalState.Config.any(),
    onRemoved: _metalState.Config.any(),
    onRepeated: _metalState.Config.any(),
    pageIndex: _metalState.Config.number(),
    spritemap: _metalState.Config.string(),
    type: _metalState.Config.string()
  };

  _metalSoy["default"].register(MetalFieldAdapter, _MetalFieldAdapter["default"]);

  var _default = MetalFieldAdapter;
  exports["default"] = _default;
  //# sourceMappingURL=MetalFieldAdapter.es.js.map
});
//# sourceMappingURL=MetalFieldAdapter.es.js.map
